# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/NetworkStateCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.devices.generic.NetworkState_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/NetworkStateCollection.proto',
  package='rst.devices.generic',
  serialized_pb='\n0rst/devices/generic/NetworkStateCollection.proto\x12\x13rst.devices.generic\x1a&rst/devices/generic/NetworkState.proto\"L\n\x16NetworkStateCollection\x12\x32\n\x07\x65lement\x18\x01 \x03(\x0b\x32!.rst.devices.generic.NetworkStateB\x1c\x42\x1aNetworkStateCollectionType')




_NETWORKSTATECOLLECTION = _descriptor.Descriptor(
  name='NetworkStateCollection',
  full_name='rst.devices.generic.NetworkStateCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.devices.generic.NetworkStateCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=113,
  serialized_end=189,
)

_NETWORKSTATECOLLECTION.fields_by_name['element'].message_type = rst.devices.generic.NetworkState_pb2._NETWORKSTATE
DESCRIPTOR.message_types_by_name['NetworkStateCollection'] = _NETWORKSTATECOLLECTION

class NetworkStateCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _NETWORKSTATECOLLECTION

  # @@protoc_insertion_point(class_scope:rst.devices.generic.NetworkStateCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\032NetworkStateCollectionType')
# @@protoc_insertion_point(module_scope)
