# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/Torques.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/Torques.proto',
  package='rst.dynamics',
  serialized_pb='\n\x1arst/dynamics/Torques.proto\x12\x0crst.dynamics\"*\n\x07Torques\x12\t\n\x01\x61\x18\x01 \x02(\x02\x12\t\n\x01\x62\x18\x02 \x02(\x02\x12\t\n\x01\x63\x18\x03 \x02(\x02\x42\rB\x0bTorquesType')




_TORQUES = _descriptor.Descriptor(
  name='Torques',
  full_name='rst.dynamics.Torques',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='rst.dynamics.Torques.a', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='rst.dynamics.Torques.b', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c', full_name='rst.dynamics.Torques.c', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=44,
  serialized_end=86,
)

DESCRIPTOR.message_types_by_name['Torques'] = _TORQUES

class Torques(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TORQUES

  # @@protoc_insertion_point(class_scope:rst.dynamics.Torques)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\013TorquesType')
# @@protoc_insertion_point(module_scope)
