# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/ObjectCollisionCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.ObjectCollision_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/ObjectCollisionCollection.proto',
  package='rst.kinematics',
  serialized_pb='\n.rst/kinematics/ObjectCollisionCollection.proto\x12\x0erst.kinematics\x1a$rst/kinematics/ObjectCollision.proto\"M\n\x19ObjectCollisionCollection\x12\x30\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1f.rst.kinematics.ObjectCollisionB\x1f\x42\x1dObjectCollisionCollectionType')




_OBJECTCOLLISIONCOLLECTION = _descriptor.Descriptor(
  name='ObjectCollisionCollection',
  full_name='rst.kinematics.ObjectCollisionCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.kinematics.ObjectCollisionCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=104,
  serialized_end=181,
)

_OBJECTCOLLISIONCOLLECTION.fields_by_name['element'].message_type = rst.kinematics.ObjectCollision_pb2._OBJECTCOLLISION
DESCRIPTOR.message_types_by_name['ObjectCollisionCollection'] = _OBJECTCOLLISIONCOLLECTION

class ObjectCollisionCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _OBJECTCOLLISIONCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.kinematics.ObjectCollisionCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\035ObjectCollisionCollectionType')
# @@protoc_insertion_point(module_scope)
