# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/SpatialAccelerationsCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.SpatialAccelerations_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/SpatialAccelerationsCollection.proto',
  package='rst.kinematics',
  serialized_pb='\n3rst/kinematics/SpatialAccelerationsCollection.proto\x12\x0erst.kinematics\x1a)rst/kinematics/SpatialAccelerations.proto\"W\n\x1eSpatialAccelerationsCollection\x12\x35\n\x07\x65lement\x18\x01 \x03(\x0b\x32$.rst.kinematics.SpatialAccelerationsB$B\"SpatialAccelerationsCollectionType')




_SPATIALACCELERATIONSCOLLECTION = _descriptor.Descriptor(
  name='SpatialAccelerationsCollection',
  full_name='rst.kinematics.SpatialAccelerationsCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.kinematics.SpatialAccelerationsCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=114,
  serialized_end=201,
)

_SPATIALACCELERATIONSCOLLECTION.fields_by_name['element'].message_type = rst.kinematics.SpatialAccelerations_pb2._SPATIALACCELERATIONS
DESCRIPTOR.message_types_by_name['SpatialAccelerationsCollection'] = _SPATIALACCELERATIONSCOLLECTION

class SpatialAccelerationsCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SPATIALACCELERATIONSCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.kinematics.SpatialAccelerationsCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\"SpatialAccelerationsCollectionType')
# @@protoc_insertion_point(module_scope)
