# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/JointVelocitiesCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.JointVelocities_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/JointVelocitiesCollection.proto',
  package='rst.kinematics',
  serialized_pb='\n.rst/kinematics/JointVelocitiesCollection.proto\x12\x0erst.kinematics\x1a$rst/kinematics/JointVelocities.proto\"M\n\x19JointVelocitiesCollection\x12\x30\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1f.rst.kinematics.JointVelocitiesB\x1f\x42\x1dJointVelocitiesCollectionType')




_JOINTVELOCITIESCOLLECTION = _descriptor.Descriptor(
  name='JointVelocitiesCollection',
  full_name='rst.kinematics.JointVelocitiesCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.kinematics.JointVelocitiesCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=104,
  serialized_end=181,
)

_JOINTVELOCITIESCOLLECTION.fields_by_name['element'].message_type = rst.kinematics.JointVelocities_pb2._JOINTVELOCITIES
DESCRIPTOR.message_types_by_name['JointVelocitiesCollection'] = _JOINTVELOCITIESCOLLECTION

class JointVelocitiesCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _JOINTVELOCITIESCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.kinematics.JointVelocitiesCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\035JointVelocitiesCollectionType')
# @@protoc_insertion_point(module_scope)
